enum ExportedKey {
Bytes(Zeroizing<Vec<u8>>),
Jwk(Box<JsonWebKey>),
}Expand description
The returned type of the successful export key operation. Bytes should be used when the key
is exported in “raw”, “spki” or “pkcs8” format. Jwk should be used when the key is exported
in “jwk” format.
Variants
Implementations
Sourceimpl ExportedKey
impl ExportedKey
fn new_bytes(bytes: Vec<u8>) -> ExportedKey
fn new_jwk(jwk: JsonWebKey) -> ExportedKey