enum ImportKeyAlgorithm {
Show 23 variants
RsassaPkcs1V1_5(RsaHashedImportParams),
RsaPss(RsaHashedImportParams),
RsaOaep(RsaHashedImportParams),
Ecdsa(EcKeyImportParams),
Ecdh(EcKeyImportParams),
Ed25519(Algorithm),
X25519(Algorithm),
Ed448(Algorithm),
X448(Algorithm),
AesCtr(Algorithm),
AesCbc(Algorithm),
AesGcm(Algorithm),
AesKw(Algorithm),
Hmac(HmacImportParams),
Hkdf(Algorithm),
Pbkdf2(Algorithm),
MlKem(Algorithm),
HybridKem(Algorithm),
MlDsa(Algorithm),
AesOcb(Algorithm),
ChaCha20Poly1305(Algorithm),
Kmac(KmacImportParams),
Argon2(Algorithm),
}Expand description
Normalized algorithm for the “importKey” operation, used as output of https://w3c.github.io/webcrypto/#dfn-normalize-an-algorithm
Variants
RsassaPkcs1V1_5(RsaHashedImportParams)
RsaPss(RsaHashedImportParams)
RsaOaep(RsaHashedImportParams)
Ecdsa(EcKeyImportParams)
Ecdh(EcKeyImportParams)
Ed25519(Algorithm)
X25519(Algorithm)
Ed448(Algorithm)
X448(Algorithm)
AesCtr(Algorithm)
AesCbc(Algorithm)
AesGcm(Algorithm)
AesKw(Algorithm)
Hmac(HmacImportParams)
Hkdf(Algorithm)
Pbkdf2(Algorithm)
MlKem(Algorithm)
HybridKem(Algorithm)
MlDsa(Algorithm)
AesOcb(Algorithm)
ChaCha20Poly1305(Algorithm)
Kmac(KmacImportParams)
Argon2(Algorithm)
Implementations
Sourceimpl ImportKeyAlgorithm
impl ImportKeyAlgorithm
fn import_key( &self, cx: &mut JSContext, global: &GlobalScope, format: KeyFormat, key_data: &[u8], extractable: bool, usages: Vec<KeyUsage>, ) -> Result<DomRoot<CryptoKey>, Error>
Sourcefn will_throw_for_key_data_length(&self, key_data_length: u32) -> bool
fn will_throw_for_key_data_length(&self, key_data_length: u32) -> bool
Return whether the import key operation specified by normalized algorithm would throw an error for every value of keyData that is a byte sequence whose length in bits is sharedKeyLength when format is “raw-secret”.